@@ -348,7 +348,8 @@ class HeatShell(object):
 
         self.subcommands = {}
         subparsers = parser.add_subparsers(metavar='<subcommand>')
-        submodule = utils.import_versioned_module(version, 'shell')
+        submodule = importutils.import_versioned_module('heatclient',
+                                                        version, 'shell')
         self._find_actions(subparsers, submodule)
         self._find_actions(subparsers, self)
         self._add_bash_completion_subparser(subparsers)
@@ -544,7 +545,8 @@ class HeatShell(object):
                 'region_name': args.os_region_name,
                 'username': args.os_username,
                 'password': args.os_password,
-                'include_pass': args.include_password
+                'include_pass': args.include_password,
+                'endpoint_override': args.heat_url,
             }
 
         client = heat_client.Client(api_version, **kwargs)
