@@ -10,8 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from heatclient.openstack.common.apiclient import base
-from heatclient.openstack.common.py3kcompat import urlutils
+from six.moves.urllib import parse
+
+from heatclient.common import base
+from heatclient.common import utils
 
 
 class SoftwareDeployment(base.Resource):
@@ -30,42 +32,45 @@ class SoftwareDeploymentManager(base.BaseManager):
 
     def list(self, **kwargs):
         """Get a list of software deployments.
+
         :rtype: list of :class:`SoftwareDeployment`
         """
-        url = '/software_deployments?%s' % urlutils.urlencode(kwargs)
+        url = '/software_deployments?%s' % parse.urlencode(kwargs)
         return self._list(url, "software_deployments")
 
     def metadata(self, server_id):
-        """Get a grouped collection of software deployment metadata for a
-        given server.
+        """Get a collection of software deployment metadata for given server.
+
         :rtype: list of :class:`SoftwareDeployment`
         """
-        url = '/software_deployments/metadata/%s' % urlutils.quote(
+        url = '/software_deployments/metadata/%s' % parse.quote(
             server_id, '')
-        resp, body = self.client.json_request('GET', url)
-        return body['metadata']
+        resp = self.client.get(url)
+        body = utils.get_response_body(resp)
+        return body.get('metadata')
 
     def get(self, deployment_id):
         """Get the details for a specific software deployment.
 
         :param deployment_id: ID of the software deployment
         """
-        resp, body = self.client.json_request(
-            'GET', '/software_deployments/%s' % deployment_id)
+        resp = self.client.get('/software_deployments/%s' % deployment_id)
+        body = utils.get_response_body(resp)
 
-        return SoftwareDeployment(self, body['software_deployment'])
+        return SoftwareDeployment(self, body.get('software_deployment'))
 
     def create(self, **kwargs):
         """Create a software deployment."""
-        resp, body = self.client.json_request(
-            'POST', '/software_deployments', data=kwargs)
-        return SoftwareDeployment(self, body['software_deployment'])
+        resp = self.client.post('/software_deployments', data=kwargs)
+        body = utils.get_response_body(resp)
+        return SoftwareDeployment(self, body.get('software_deployment'))
 
     def update(self, deployment_id, **kwargs):
         """Update a software deployment."""
-        resp, body = self.client.json_request(
-            'PUT', '/software_deployments/%s' % deployment_id, data=kwargs)
-        return SoftwareDeployment(self, body['software_deployment'])
+        resp = self.client.put('/software_deployments/%s' %
+                               deployment_id, data=kwargs)
+        body = utils.get_response_body(resp)
+        return SoftwareDeployment(self, body.get('software_deployment'))
 
     def delete(self, deployment_id):
         """Delete a software deployment."""
